package namensraumdurchsuchen;

import java.util.Properties;
import org.omg.CORBA.*;
import org.omg.CosNaming.*;

/**
 * Title:        Namensraum durchsuchen
 * Description:  untersuchen eines Namensraumes
 * Copyright:    Copyright (c) J.M.Joller
 * Company:      Joller-Voss
 * @author J.M.Joller
 * @version 1.0
 */

public class Client {
   public static void main(String args[])
   {
      try {
        /**
         * 2. Setzen von Host und Port
         */
        Properties props = new Properties();
        props.put("org.omg.CORBA.ORBInitialPort", "1050");
        props.put("org.omg.CORBA.ORBInitialHost", "localhost");
        ORB orb = ORB.init(args, props);

        /**
         * 3. bestimmen des initialen Namenskontextes
         *    'NameService' gilt bei jedem ORB!
         */

        NamingContextExt nc =
          NamingContextExtHelper.narrow(orb.resolve_initial_references(
            "NameService"));

        /**
         * 4. Auflisten aller Bindungen im Kontext
         *    list() bezieht sich immer auf einen Kontext!
         */

        BindingListHolder bl = new BindingListHolder();
        BindingIteratorHolder blIt= new BindingIteratorHolder();
        // maximal 1000
        nc.list(1000, bl, blIt);

        /**
         * 5. Bestimme das Array mit den Bindings
         */

        Binding bindings[] = bl.value;

        /**
         * 6. Bindungs auflisten und ausgeben
         */

        for (int i=0; i < bindings.length; i++) {

            int lastIx = bindings[i].binding_name.length-1;

            // ist die Bindung ein Kontext?
            if (bindings[i].binding_type == BindingType.ncontext) {
              System.out.println( "Context: " +
                bindings[i].binding_name[lastIx].id);

            // nein: dann ist es ein Objekt
            } else {
                System.out.println("Objekt: " +
                  bindings[i].binding_name[lastIx].id);
            }
        }

       } catch (Exception e) {
        e.printStackTrace(System.err);
       }
   }
}
