package objekteinnamensraumeintragen;

// 1. importiere die bentigten libraries:
import java.util.Properties;
import org.omg.CORBA.*;
import org.omg.CosNaming.*;

/**
 * Title:        Namensraum Eintrge
 * Description:  Kreieren eines Namenskontextes
 * Eintragen mehrerer Objekte in diesen Kontext.
 * Copyright:    Copyright (c) J.M.Joller
 * Company:      Joller-Voss
 * @author J.M.Joller
 * @version 1.0
 */

public class Client {
   public static void main(String args[]) {
      try {
        // 2. Port und Host setzen und ORB instanzieren
        // 1050 / localhost
        Properties props = new Properties();
        props.put("org.omg.CORBA.ORBInitialPort", "1050");
        props.put("org.omg.CORBA.ORBInitialHost", "localhost");

        ORB orb = ORB.init(args, props);
        // 3. initialer Namenskontext : ctx
        //    und zuordnen an eine dummy Objektreferenz
        NamingContextExt ctx =
          NamingContextExtHelper.narrow(orb.resolve_initial_references(
            "NameService"));
        org.omg.CORBA.Object objref = ctx;

        // 4. Binden des Namens "plans" an die Objektreferenz
        //    "plans" wird an die dummy Objektreferenz gebunden.
        //    rebind statt bind: damit werden allfllig bereits vorhandene
        //    Bindungen einfach erneuert / berschrieben.
        NameComponent name1[] = ctx.to_name("plans");
        ctx.rebind(name1, objref);
        System.out.println("plans rebind erfolgreich!");

        // 5. Kreieren eines neuen Namenskontextes "Personal".
        //    Binden weiterer Objektreferenzen
        //    neuer Context
        NameComponent name2[] = ctx.to_name("Personal");
        // binden des Contextes ans root (plans)
        // NamingContextExt ctx2 = ctx.bind_new_context(name2);
        NamingContext ctx2 = ctx.bind_new_context(name2);
        System.out.println("Neuer Namenskontext, Personal, hinzugefuegt!");

        // 6. Binde "schedule" und "calendar" an die dummy Objektreferenz.
        //    'Binden' heisst, dass eine neue Namensbindung in einem gegebenen
        //     Namenskontext eingetragen wird.
        //     Namen werden immer relativ zu einem Kontext aufgelst -
        //     es gibt also keine absoluten Namen.
        //     Jetzt binden wir die dummy Objektreferenz an "schedule" und
        //     "calendar" im "Personal" Namenskontext (ctx2).
        NameComponent name3[] = ctx.to_name("schedule");
        ctx2.rebind(name3, objref);
        System.out.println("schedule rebind erfolgreich!");

        NameComponent name4[] = ctx.to_name("calendar");
        ctx2.rebind(name4, objref);
        System.out.println("calendar rebind erfolgreich!");
    } catch (Exception e) {
        e.printStackTrace(System.err);
    }
  }
}
