package poaerstesbeispiel;

/**
 * Title:        CORBA - Portable Object Adapter Vererbungsmodell
 * Description:
 * Copyright:    Copyright (c) J.M.Joller
 * Company:      Joller-Voss
 * @author J.M.Joller
 * @version 1.0
 */

 // aus IDL
import HalloApp.*;
// Namensraum
import org.omg.CosNaming.*;
// Exceptions im Namensraum
import org.omg.CosNaming.NamingContextPackage.*;
// alle CORBA Basisklassen
import org.omg.CORBA.*;
// POA
import org.omg.PortableServer.*;
import org.omg.PortableServer.POA;
// Properties zum Setzen einiger Eigenschaften
import java.util.Properties;

class HalloImpl extends HalloPOA { // HalloPOA enthlt bereits CORBA Teile
  private ORB orb;

  public void setORB(ORB orb_val) { // eindeutiges Kennzeichnen unseres ORBs
    orb = orb_val;
  }

  // implementieren der IDL Methoden
  public String wieGehts() {
    System.out.println("[HelloImpl.wieGehts()]Aufruf der Servant Methode");
    return "Mir geht's gut! Wie geht's Dir?\n";
  }

  // in IDL wird eine shutdown() Methode definiert
  public void shutdown() {
    System.out.println("[HelloImpl.shutdown()]Aufruf der Servant Methode");
    orb.shutdown(false);
  }
}


public class Server {

  public static void main(String args[]) {
    try{
      // Kreieren und Initialisieren des ORB
      System.out.println("[POA-Server.main()]Kreieren und Initialisieren des ORB");
      ORB orb = ORB.init(args, null);

      // Bestimmen einer Referenz auf die rootpoa & aktivieren des POAManager
      System.out.println("[POA-Server.main()]Bestimmen einer Referenz auf die rootpoa & aktivieren des POAManager");
      POA rootpoa = (POA)orb.resolve_initial_references("RootPOA");
      rootpoa.the_POAManager().activate();

      // kreieren des Servants und registrieren beim ORB
      System.out.println("[POA-Server.main()]Kreieren des Servants und registrieren beim ORB");
      HalloImpl halloImpl = new HalloImpl();
      halloImpl.setORB(orb);

      // Bestimmen einer Objektreferenz zum Servant
      System.out.println("[POA-Server.main()]Bestimmen einer Objektreferenz zum Servant");
      org.omg.CORBA.Object ref = rootpoa.servant_to_reference(halloImpl);
      Hallo href = HalloHelper.narrow(ref);

      // Bestimme den root naming context
      // NameService nutzt den transient name service
      System.out.println("[POA-Server.main()]Bestimme den root naming context");
      org.omg.CORBA.Object objRef =
          orb.resolve_initial_references("NameService");
      // Einsatz des NamingContextExt, welcher Teil der Interoperable
      // Naming Service (INS) Spezifikation ist.
      System.out.println("[POA-Server.main()]Einsatz des NamingContextExt");
      NamingContextExt ncRef = NamingContextExtHelper.narrow(objRef);

      // binden der Objekt Referenz im Naming / Namensraum
      System.out.println("[POA-Server.main()]Binden der Objekt Referenz im Namensraum");
      String name = "POA Grsse";
      NameComponent path[] = ncRef.to_name( name );
      ncRef.rebind(path, href);

      System.out.println("[POA-Server.main()]Der Server ist bereit und wartet auf Anfragen ...");

      // Warten auf Methodenaufrufe durch den Client
      orb.run();
    }
      catch (Exception e) {
        System.err.println("[POA-Server.Exception] " + e);
        e.printStackTrace(System.out);
      }
      System.out.println("[POA-Server.main()]Der Server wird herunter gefahren ...");
  }
}
