//package persistenz;

import java.util.Properties;
import org.omg.CORBA.ORB;
import org.omg.CORBA.OBJ_ADAPTER;
import org.omg.CosNaming.NamingContext;
import org.omg.CosNaming.NamingContextHelper;
import org.omg.CosNaming.NameComponent;
import org.omg.PortableServer.POA;

import Persistent.*;

/**
 * Title:        Serverseitige Persistenz in CORBA mit POA
 * Description:  Einfaches Beispiel fr den Einsatz des POA unter Bercksichtigung der Persistenz des Servers und des Namensdienstes
 * Copyright:    Copyright (c) J.M.Joller
 * Company:      Joller-Voss
 * @author J.M.Joller
 * @version 1.0
 */

public class PersistenterClient {

    public static void main(String args[]) {

        try {
            System.out.println( "[PersistenterClient]Start" );
            // 1) Instanzieren des ORBs
            ORB orb = ORB.init(args, null);

            // 2) Auflsen des Servant Objekts ber eine URL
            // Der Namensdienst muss gestartet sein und
            // der Host 'localhost', der Port 1050 sein
            // 'PersistenteVariante' steht im Namensraum (durch den Server)
            org.omg.CORBA.Object obj = orb.string_to_object(
                "corbaname::localhost:1050#PersistenterServer");

            Hallo persistentHallo = HalloHelper.narrow( obj );

            // 3) Aufruf der wieGehts() Methode alle 60 Sekunden und Shutdown
            // Der Server wird automatisch gestartet, da er als persistent
            // definiert wurde.
            while( true ) {
                System.out.println( "[PersistenterClient]Aufruf des persistenten Servers..." );
                String meldungVomServer = persistentHallo.wieGehts();
                System.out.println("[PersistenterClient]Message vom persistenten Server: " +
                    meldungVomServer );
                System.out.println( "[PersistenterClient]Herunterfahren des persistenten Servers.." );
                persistentHallo.shutdown( );
                Thread.sleep( 60000 );
            }
        } catch ( Exception e ) {
            System.err.println( "[PersistenterClient]Exception im persistenten Client..." + e );
            e.printStackTrace( );
        }
    }
}
