//package persistenz;

import java.util.Properties;
import org.omg.CORBA.Object;
import org.omg.CORBA.ORB;
import org.omg.CosNaming.NameComponent;
import org.omg.CosNaming.NamingContextExt;
import org.omg.CosNaming.NamingContextExtHelper;
import org.omg.CORBA.Policy;
import org.omg.PortableServer.POA;
import org.omg.PortableServer.*;
import org.omg.PortableServer.Servant;

/**
 * Title:        Serverseitige Persistenz in CORBA mit POA
 * Description:  Einfaches Beispiel fr den Einsatz des POA
 *               unter Bercksichtigung der Persistenz des Servers
 *               und des Namensdienstes
 * Copyright:    Copyright (c) J.M.Joller
 * Company:      Joller-Voss
 * @author J.M.Joller
 * @version 1.0
 */

public class PersistenterServer {

    public static void install(org.omg.CORBA.ORB orb) {
      System.out.println("Install wurde gestartet");
    }

    public static void main( String args[] ) {
        System.out.println("[PersistenterServer]Start");
        Properties properties = System.getProperties();
        properties.put( "org.omg.CORBA.ORBInitialHost","localhost" );
        properties.put( "org.omg.CORBA.ORBInitialPort", "1050" );
        System.out.println("[PersistenterServer]Properties:");
        System.out.println("[PersistenterServer]\tORBInitialHost : "+properties.getProperty("org.omg.CORBA.ORBInitialHost"));
        System.out.println("[PersistenterServer]\tORBInitialPort : "+properties.getProperty("org.omg.CORBA.ORBInitialPort"));
        try {
            // 1) Instanzieren des ORBs
            System.out.println("[PersistenterServer]ORB.init()");
            ORB orb = ORB.init(args, properties);

            // 2) Instanzieren des Servants
            PersistenterServant servant = new PersistenterServant(orb);
            System.out.println("[PersistenterServer]new PersistenterServant(orb)");

            // 3) Servant mit persistentem POA
            // *******************
            // 3-1) rootPOA
            POA rootPOA = (POA)orb.resolve_initial_references("RootPOA");
            System.out.println("[PersistenterServer](POA)orb.resolve_initial_references('RootPOA')");

            // 3-2) Persistent Policy
            System.out.println("[PersistenterServer]POA Policy");
            Policy[] persistentPolicy = new Policy[1];
            persistentPolicy[0] = rootPOA.create_lifespan_policy(
                LifespanPolicyValue.PERSISTENT);
            // 3-3) Kreiere POA mit der obigen Policy
            POA persistentPOA = rootPOA.create_POA("persistenterPOA", null,
                persistentPolicy );
            // 3-4) Aktiviere den POAManager des persistenten POA
            // Falls dieser Schritt fehlt, bleibt der persistente Server stehen,
            // weil der POAManager im 'HOLD' Zustand stecken bleibt.
            persistentPOA.the_POAManager().activate( );
            // *********************** Ende 3)

            // 4) Assoziiere den Servant mit dem persistenten POA
            persistentPOA.activate_object( servant );
            System.out.println("[PersistenterServer]POA.activate_object(servant)");

            // 5) Auflsen des RootNaming Kontextes und binden eines Namens
            // fr das Servant Objekt
            /** HINWEIS:
             *  Falls der Server persistent ist, dann sollte auch ein
             *  persistenter Namensdienst eingesetzt werden.
             *  Im Falle von ORBD ist die Wahl von 'NameService' in der
             *  Methode resolve_initial_reference() eine gute Wahl.
             */
            System.out.println("[PersistenterServer]Naming Context");
            org.omg.CORBA.Object obj = orb.resolve_initial_references(
                "NameService" );
            NamingContextExt rootContext = NamingContextExtHelper.narrow( obj );

            NameComponent[] nc = rootContext.to_name(
                "PersistenterServer" );
            rootContext.rebind( nc, persistentPOA.servant_to_reference(
                servant ) );

            // 6) Warten auf Kundenanfragen
            System.out.println("[PersistenterServer]orb.run() - warten auf Clients");
            orb.run();
        } catch ( Exception e ) {
            System.err.println( "Exception beim Starten des persistenten Servers " + e );
        }
    }
}
