
import DelegationsModell.*;
import org.omg.CosNaming.*;
import org.omg.CosNaming.NamingContextPackage.*;
import org.omg.CORBA.*;
import org.omg.PortableServer.*;
import org.omg.PortableServer.POA;

import java.util.Properties;


/**
 * Title:        Tie / Delegations-Modell
 * Description:  Beispiel fr den Einsatz des Delegationsmodells
 * mit POA
 * Copyright:    Copyright (c) J.M.Joller
 * Company:      Joller-Voss
 * @author J.M.Joller
 * @version 1.0
 */

public class DelegationsServer{

  public static void main(String args[]){
    System.out.println("[DelegationsServer]Start");
    try{
      // kreieren und initialisieren des ORBs
      System.out.println("[DelegationsServer]ORB.init()");
      ORB orb = ORB.init(args, null);

      // Referenz auf rootpoa & aktivieren des POAManager
      System.out.println("[DelegationsServer]Referenz auf rootPOA");
      POA rootpoa = (POA)orb.resolve_initial_references("RootPOA");
      System.out.println("[DelegationsServer]aktivieren des POAManagers");
      rootpoa.the_POAManager().activate();

      // Servant kreieren und beim ORB registrieren
      System.out.println("[DelegationsServer]Servant kreieren und registrieren");
      DelegationsServantImpl halloImpl = new DelegationsServantImpl();
      halloImpl.setORB(orb);

      // kreieren des Tie; der Servant ist das Delegate Objekt
      System.out.println("[DelegationsServer]Delegation kreieren");
      HalloPOATie tie = new HalloPOATie(halloImpl, rootpoa);

      // objectRef fr den tie bestimmen
      // und implizites Aktivieren des Objekts
      Hallo href = tie._this(orb);

      // bestimme root naming context
      System.out.println("[DelegationsServer]Namenskontext");
      org.omg.CORBA.Object objRef = orb.resolve_initial_references("NameService");

      // nutze den NamingContextExt(Teil des Interoperable
      // Naming Service).
      NamingContextExt ncRef = NamingContextExtHelper.narrow(objRef);

      // binden der Objekt Referenz im Namensraum
      System.out.println("[DelegationsServer]binden des Servants");
      String name = "DelegationsVariante";
      NameComponent path[] = ncRef.to_name( name );
      ncRef.rebind(path, href);

      System.out.println("[DelegationsServer]Der Server ist bereit und wartet auf Anfragen ...");

      // warten auf Client Anfragen
      orb.run();
      }

    catch (Exception e){
      System.err.println("ERROR: " + e);
      e.printStackTrace(System.out);
    }

    System.out.println("[DelegationsServer]Der Server wird heruntergefahren ...");

  }
}

