package rmooveriiopmitpoa;

import javax.naming.InitialContext;
import javax.naming.Context;
import javax.rmi.PortableRemoteObject ;
import com.sun.corba.se.internal.POA.POAORB;
import org.omg.PortableServer.*;
import java.util.*;
import org.omg.CORBA.*;
import javax.rmi.CORBA.Stub;
import javax.rmi.CORBA.Util;

/**
 * Title:        RMI over IIOP
 * Description:  RMI over IIOP mit POA
 * Copyright:    Copyright (c) J.M.Joller
 * Company:      Joller-Voss
 * @author J.M.Joller
 * @version 1.0
 */

public class Server {
  public Server(String[] args) {
    try {
      System.out.println("[Server]Start");
      System.out.println("[Server]Setzen der Laufzeit Eigenschaften");
      Properties p = System.getProperties();
      // Laufzeit Eigenschaften / Properties
      p.put("org.omg.CORBA.ORBClass",
          "com.sun.corba.se.internal.POA.POAORB");
      p.put("org.omg.CORBA.ORBSingletonClass",
          "com.sun.corba.se.internal.corba.ORBSingleton");

      ORB orb = ORB.init( args, p );

      System.out.println("[Server]POA");
      // POA Definition und Instanzierung
      System.out.println("[Server]POA - setzen des Roots");
      // 1) rootPOA bestimmen
      POA rootPOA = (POA)orb.resolve_initial_references("RootPOA");

      // 2) kreiere den POA mit den entsprechenden Policies
      System.out.println("[Server]POA - Definition der Policies");
      Policy[] tpolicy = new Policy[3];
      tpolicy[0] = rootPOA.create_lifespan_policy(
        LifespanPolicyValue.TRANSIENT );
      tpolicy[1] = rootPOA.create_request_processing_policy(
        RequestProcessingPolicyValue.USE_ACTIVE_OBJECT_MAP_ONLY );
      tpolicy[2] = rootPOA.create_servant_retention_policy(
        ServantRetentionPolicyValue.RETAIN);

      System.out.println("[Server]POA - Definition von 'MeinTransienterPOA'");
      POA tPOA = rootPOA.create_POA("MeinTransienterPOA", null, tpolicy);


      // 3) Aktivieren des POAs
      // der POAManager ist dann im HOLD Zustand
      System.out.println("[Server]POA - Aktivierung");
      tPOA.the_POAManager().activate();

      // 4) Instanzieren des Servants und aktivieren der Tie
      // POA Policy : USE_ACTIVE_OBJECT_MAP_ONLY
      System.out.println("[Server]Servant - Instanzierung");
      Servant servantRef = new Servant();
      System.out.println("[Server]Servant - Tie Instanzierung");
      _Servant_Tie tie = (_Servant_Tie)Util.getTie( servantRef );
      String halloId = "RMIoverIIOPmitPOA";
      byte[] id = halloId.getBytes();
      System.out.println("[Server]Servant - Aktivierung");
      tPOA.activate_object_with_id( id, tie );

      // 5) Publizieren der Objektreferenz mit der selben Objekt ID wie
      //    das Tie Objekt
      System.out.println("[Server]NamingContext - Instanzierung");
      Context initialNamingContext = new InitialContext();
      System.out.println("[Server]NamingContext - POAServer eintragen");
      initialNamingContext.rebind("POAServer",
        tPOA.create_reference_with_id(id,
          tie._all_interfaces(tPOA,id)[0]) );

      // 6) waren auf Clients
      System.out.println("[Server]warten auf Clients");
      orb.run();
    }
      catch (Exception e) {
        System.out.println("[Server]Probleme im Server: " + e);
        e.printStackTrace();
      }
  }


  public static void main(String args[]) {
    new Server( args );
  }
}
